@@ -388,6 +388,39 @@ class TestBuild:
             },
         )
 
+    def test_submit_build_no_cache(self, build, build_attrs, mocker):
+        build_attrs["no_cache"] = True
+        post_request = mocker.patch("tuxsuite.build.post_request")
+        api_build_url = (
+            build_attrs["tuxapi_url"] + "/v1/groups/tuxsuite/projects/unittests/builds"
+        )
+
+        build.no_cache = True
+        build.build()
+        post_request.assert_called_with(
+            api_build_url,
+            mocker.ANY,
+            {
+                "builds": [
+                    {
+                        "git_repo": build_attrs["git_repo"],
+                        "git_ref": build_attrs["git_ref"],
+                        "toolchain": build_attrs["toolchain"],
+                        "target_arch": build_attrs["target_arch"],
+                        "kconfig": [build_attrs["kconfig"]],
+                        "build_name": build_attrs["build_name"],
+                        "client_token": mocker.ANY,
+                        "environment": {},
+                        "targets": [],
+                        "make_variables": {},
+                        "kernel_image": build_attrs["kernel_image"],
+                        "no_cache": True,
+                    },
+                ],
+                "patches": {},
+            },
+        )
+
 
 class TestWatch:
     @staticmethod
