@@ -780,13 +780,14 @@ def test_test_cli(mocker, tuxsuite_config):
     test.assert_called_once_with(
         device="qemu-arm64",
         kernel="https://example.com/vmlinux",
+        ap_romfw=None,
         mcp_fw=None,
         mcp_romfw=None,
         modules=None,
         rootfs=None,
         scp_fw=None,
         scp_romfw=None,
-        uefi=None,
+        fip=None,
         parameters={},
         tests=[],
         boot_args=None,
@@ -809,13 +810,14 @@ def test_test_cli(mocker, tuxsuite_config):
     test.assert_called_once_with(
         device="qemu-arm64",
         kernel="https://example.com/vmlinux",
+        ap_romfw=None,
         mcp_fw=None,
         mcp_romfw=None,
         modules="https://example.com/modules.tar.xz",
         rootfs=None,
         scp_fw=None,
         scp_romfw=None,
-        uefi=None,
+        fip=None,
         parameters={},
         tests=["ltp-smoke"],
         boot_args=None,
@@ -837,13 +839,14 @@ def test_test_cli(mocker, tuxsuite_config):
     test.assert_called_once_with(
         device="qemu-arm64",
         kernel=None,
+        ap_romfw=None,
         mcp_fw=None,
         mcp_romfw=None,
         modules=None,
         rootfs=None,
         scp_fw=None,
         scp_romfw=None,
-        uefi=None,
+        fip=None,
         parameters={},
         tests=["ltp-smoke"],
         boot_args=None,
@@ -856,12 +859,13 @@ def test_test_cli(mocker, tuxsuite_config):
         tuxsuite.cli.test,
         [
             "--device=fvp-morello-android",
+            "--ap-romfw=tf_bl1.bin",
             "--mcp-fw=mcp_fw.bin",
             "--mcp-romfw=mcp_romfw.bin",
             "--rootfs=rootfs.ext4",
             "--scp-fw=scp_fw.bin",
             "--scp-romfw=scp_romfw.bin",
-            "--uefi=uefi.bin",
+            "--fip=fip.bin",
             "--parameters=USERDATA=userdata.tar.xz",
             "--parameters=TC_URL=toolchain.tar.xz",
             "--tests=lldb",
@@ -873,13 +877,14 @@ def test_test_cli(mocker, tuxsuite_config):
     test.assert_called_once_with(
         device="fvp-morello-android",
         kernel=None,
+        ap_romfw="tf_bl1.bin",
         mcp_fw="mcp_fw.bin",
         mcp_romfw="mcp_romfw.bin",
         modules=None,
         rootfs="rootfs.ext4",
         scp_fw="scp_fw.bin",
         scp_romfw="scp_romfw.bin",
-        uefi="uefi.bin",
+        fip="fip.bin",
         parameters={"USERDATA": "userdata.tar.xz", "TC_URL": "toolchain.tar.xz"},
         tests=["lldb"],
         boot_args=None,
