@@ -252,6 +252,7 @@ def plan_json():
                     "device": "qemu-x86_64",
                     "uid": "1qsx5iBMtsjD24OgjWW9tatj4HE",
                     "kernel": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCX/bzImage",
+                    "ap_romfw": None,
                     "mcp_fw": None,
                     "mcp_romfw": None,
                     "modules": None,
@@ -259,7 +260,7 @@ def plan_json():
                     "rootfs": None,
                     "scp_fw": None,
                     "scp_romfw": None,
-                    "uefi": None,
+                    "fip": None,
                     "tests": ["boot", "ltp-smoke"],
                     "user": None,
                     "user_agent": None,
@@ -279,6 +280,7 @@ def plan_json():
                     "device": "qemu-x86_64",
                     "uid": "1qsx5iBMtsjD24OgjWW9tatj4HE",
                     "kernel": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCX/bzImage",
+                    "ap_romfw": None,
                     "mcp_fw": None,
                     "mcp_romfw": None,
                     "modules": None,
@@ -286,7 +288,7 @@ def plan_json():
                     "rootfs": None,
                     "scp_fw": None,
                     "scp_romfw": None,
-                    "uefi": None,
+                    "fip": None,
                     "tests": ["boot", "ltp-smoke"],
                     "user": None,
                     "user_agent": None,
@@ -306,6 +308,7 @@ def plan_json():
                     "device": "qemu-x86_64",
                     "uid": "1qsx5iBMtsjD24OgjWW9tatj4HE",
                     "kernel": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCX/bzImage",
+                    "ap_romfw": None,
                     "mcp_fw": None,
                     "mcp_romfw": None,
                     "modules": None,
@@ -313,7 +316,7 @@ def plan_json():
                     "rootfs": None,
                     "scp_fw": None,
                     "scp_romfw": None,
-                    "uefi": None,
+                    "fip": None,
                     "tests": ["boot", "ltp-smoke"],
                     "user": None,
                     "user_agent": None,
@@ -333,6 +336,7 @@ def plan_json():
                     "device": "qemu-x86_64",
                     "uid": "1qsx5iBMtsjD24OgjWW9tatj4HE",
                     "kernel": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCX/bzImage",
+                    "ap_romfw": None,
                     "mcp_fw": None,
                     "mcp_romfw": None,
                     "modules": None,
@@ -340,7 +344,7 @@ def plan_json():
                     "rootfs": None,
                     "scp_fw": None,
                     "scp_romfw": None,
-                    "uefi": None,
+                    "fip": None,
                     "tests": ["boot", "ltp-smoke"],
                     "user": None,
                     "user_agent": None,
@@ -360,6 +364,7 @@ def plan_json():
                     "device": "qemu-x86_64",
                     "uid": "1qsx5iBMtsjD24OgjWW9tatj4HE",
                     "kernel": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCX/bzImage",
+                    "ap_romfw": None,
                     "mcp_fw": None,
                     "mcp_romfw": None,
                     "modules": None,
@@ -367,7 +372,7 @@ def plan_json():
                     "rootfs": None,
                     "scp_fw": None,
                     "scp_romfw": None,
-                    "uefi": None,
+                    "fip": None,
                     "tests": ["boot", "ltp-smoke"],
                     "user": None,
                     "user_agent": None,
@@ -387,6 +392,7 @@ def plan_json():
                     "device": "qemu-x86_64",
                     "uid": "1qsx5iBMtsjD24OgjWW9tatj4HE",
                     "kernel": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCX/bzImage",
+                    "ap_romfw": None,
                     "mcp_fw": None,
                     "mcp_romfw": None,
                     "modules": None,
@@ -394,7 +400,7 @@ def plan_json():
                     "rootfs": None,
                     "scp_fw": None,
                     "scp_romfw": None,
-                    "uefi": None,
+                    "fip": None,
                     "tests": ["boot", "ltp-smoke"],
                     "user": None,
                     "user_agent": None,
