@@ -173,8 +173,9 @@ def test_submit(config, plan_config, mocker):
         if url == "https://tuxapi.tuxsuite.com/v1/groups/tuxgrp/projects/tuxprj/builds":
             assert isinstance(data, dict)
             assert len(data["builds"]) == 11
+            builds = data["builds"]
             index = 0
-            for p, d in zip(cfg.plan, data["builds"]):
+            for p, d in zip(cfg.plan, builds):
                 assert p["build"]["toolchain"] == d["toolchain"]
                 assert p["build"]["target_arch"] == d["target_arch"]
                 assert [p["build"]["kconfig"]] == d["kconfig"]
@@ -187,7 +188,7 @@ def test_submit(config, plan_config, mocker):
                 d["uid"] = f"my-build-{index:02}"
                 d["download_url"] = f"http://url/{d['uid']}"
                 index += 1
-            return data
+            return builds
         if url == "https://tuxapi.tuxsuite.com/v1/groups/tuxgrp/projects/tuxprj/tests":
             assert isinstance(data, list)
             assert len(data) == 21
