@@ -595,6 +595,7 @@ class Plan(HeadersMixin):
                             project=self.project,
                             device=test["device"],
                             kernel=test.get("kernel"),
+                            ap_romfw=test.get("ap_romfw"),
                             mcp_fw=test.get("mcp_fw"),
                             mcp_romfw=test.get("mcp_romfw"),
                             modules=test.get("modules"),
@@ -603,7 +604,7 @@ class Plan(HeadersMixin):
                             scp_fw=test.get("scp_fw"),
                             scp_romfw=test.get("scp_romfw"),
                             tests=test.get("tests", []),
-                            uefi=test.get("uefi"),
+                            fip=test.get("fip"),
                             boot_args=test.get("boot_args"),
                         )
                     )
@@ -795,6 +796,7 @@ class Test(HeadersMixin):
     project = attrib()
     device = attrib()
     kernel = attrib(default=None)
+    ap_romfw = attrib(default=None)
     mcp_fw = attrib(default=None)
     mcp_romfw = attrib(default=None)
     modules = attrib(default=None)
@@ -802,7 +804,7 @@ class Test(HeadersMixin):
     rootfs = attrib(default=None)
     scp_fw = attrib(default=None)
     scp_romfw = attrib(default=None)
-    uefi = attrib(default=None)
+    fip = attrib(default=None)
     tests = attrib(default=[])
     boot_args = attrib(default=None)
     wait_for = attrib(default=None)
@@ -821,13 +823,14 @@ class Test(HeadersMixin):
         data = {
             "device": self.device,
             "kernel": self.kernel,
+            "ap_romfw": self.ap_romfw,
             "mcp_fw": self.mcp_fw,
             "mcp_romfw": self.mcp_romfw,
             "parameters": self.parameters,
             "rootfs": self.rootfs,
             "scp_fw": self.scp_fw,
             "scp_romfw": self.scp_romfw,
-            "uefi": self.uefi,
+            "fip": self.fip,
         }
         if self.modules:
             data["modules"] = self.modules
