@@ -694,6 +694,7 @@ DEVICES = [
     "qemu-ppc64le",
     "qemu-riscv",
     "qemu-riscv64",
+    "qemu-s390",
     "qemu-sparc64",
     "qemu-x86_64",
 ]
@@ -764,13 +765,19 @@ def test_options(required):
         option(
             "--scp-fw", help="URL of the SCP firmware to test", default=None, type=str
         ),
+        option(
+            "--ap-romfw",
+            help="URL of the AP ROM firmware to test",
+            default=None,
+            type=str,
+        ),
         option(
             "--scp-romfw",
             help="URL of the SCP ROM firmware to test",
             default=None,
             type=str,
         ),
-        option("--uefi", help="URL of the UEFI to test", default=None, type=str),
+        option("--fip", help="URL of the fip.bin to test", default=None, type=str),
         option(
             "--parameters",
             help="test parameters as KEY=VALUE",
@@ -852,6 +859,7 @@ test_description = (
 def test(
     device,
     kernel,
+    ap_romfw,
     mcp_fw,
     mcp_romfw,
     modules,
@@ -859,7 +867,7 @@ def test(
     rootfs,
     scp_fw,
     scp_romfw,
-    uefi,
+    fip,
     tests,
     boot_args,
     wait_for,
@@ -924,13 +932,14 @@ def test(
         test = tuxsuite.Test(
             device=device,
             kernel=kernel,
+            ap_romfw=ap_romfw,
             mcp_fw=mcp_fw,
             mcp_romfw=mcp_romfw,
             modules=modules,
             rootfs=rootfs,
             scp_fw=scp_fw,
             scp_romfw=scp_romfw,
-            uefi=uefi,
+            fip=fip,
             parameters=params,
             tests=tests,
             boot_args=boot_args,
